==> n3_sdk-1.3.1r03.zip: n3_sdk-1.3.1/lib/framework/n3_base_application_lite.js <==
/**
 * @N3C.ProjectName@ application
 */
// setup drawers
N3C.@N3.AppClassName@ = Class.cast({
    // ######################
    // ##### BASE CLASS  ####
    // ######################
    Extends: N3C.Application,

    // ######################
    // ##### INTERFACES #####
    // ######################
    Implements: null,

    // ############################
    // ##### CLASS PROPERTIES #####
    // ############################
    Static: {
        /**
         * start application
         * ____________
         *| PRAMETERS                                                                                                       
         * ( add parameters if necessarry )
         * ____________
         *| OUTPUT
         * [Object] ... application
         */
        start: function() {
            return new this();
        }
    },

    // ###############################
    // ##### INSTANCE PROPERTIES  ####
    // ###############################

    // #######################
    // ##### CONSTRUCTOR #####
    // #######################
    /**
     * constructor
     */
    newInstance: function() {
        // call super class constructor
        this.superClass();

        N3C.windowComponent().append(
            new N3C.Panel("n3c_lite_sample_application", "sample_design").setText("Hellow world")
        );
    },

    // ###########################
    // ##### VIRTUAL METHODS #####
    // ###########################
    Virtual: {
    },

    // ############################
    // ##### ABSTRACT METHODS #####
    // ############################
    Abstract: {
    },

    // ##########################
    // ##### PUBLIC METHODS  ####
    // ##########################

    // ###########################
    // ##### PRIVATE METHODS  ####
    // ###########################
    Private: {
    },

    // ##########################################
    // ##### IMPLEMENTNTS INTERFACE METHODS  ####
    // ##########################################

    // ####################################
    // ##### OVERRIDE VIRTUAL METHODS  ####
    // ####################################

    // ###################################
    // ##### DEFINE ABSTRACT METHODS  ####
    // ###################################
    /**
     * terminate procerss
     */
    onTerminate: function() {},

    // #######################
    // ##### INNER CLASS #####
    // #######################

    // #######################
    // ##### CLASS LOADER ####
    // #######################
    Loader: function() {
        Design.cast({
            ".sample_design": {
                "font-size": "3.0em",
                "word-wrap": "word-break"
            }
        });
    }
});

==> n3_sdk-1.3.3r03.zip: n3_sdk-1.3.3/lib/framework/n3_base_application_lite.js <==
/**
 * @N3.ProjectName@ application
 */
// setup drawers
N3C.@N3.AppClassName@ = Class.cast({
    // ######################
    // ##### BASE CLASS  ####
    // ######################
    Extends: N3C.Application,

    // ######################
    // ##### INTERFACES #####
    // ######################
    Implements: null,

    // ###############################
    // ##### CONSTANT PROPERTIES #####
    // ###############################
    Const: {
    },

    // ############################
    // ##### CLASS PROPERTIES #####
    // ############################
    Static: {
        /**
         * start application
         * ____________
         *| PRAMETERS                                                                                                       
         * ( add parameters if necessarry )
         * ____________
         *| OUTPUT
         * [Object] ... application
         */
        start: function() {
            return new this();
        }
    },

    // ###############################
    // ##### INSTANCE PROPERTIES  ####
    // ###############################

    // #######################
    // ##### CONSTRUCTOR #####
    // #######################
    /**
     * constructor
     */
    newInstance: function() {
        // call super class constructor
        this.superClass();

        var n3c = N3C;

        // base panel

        n3c.windowComponent().add(
            new n3c.Panel("n3c_lite_sample_application_base_panel", "base_panel").add(
                new n3c.Panel("n3c_lite_sample_application_title", "application_title").setText("Hello world")
            )
        );

        // invoke termiate receiver
        this.invokeTerminateReceiver();
    },

    // ##########################################
    // ##### IMPLEMENTNTS INTERFACE METHODS  ####
    // ##########################################

    // ####################################
    // ##### OVERRIDE VIRTUAL METHODS  ####
    // ####################################

    // ###################################
    // ##### DEFINE ABSTRACT METHODS  ####
    // ###################################
    /**
     * get current page
     *  __________
     * | OUTPUT 
     * [N3C] ... page component
     */
    getCurrentPage: function() { return null; },

    // ###########################
    // ##### PRIVATE METHODS  ####
    // ###########################

    // #########################
    // ##### INNER CLASSES #####
    // #########################

    // #######################
    // ##### CLASS LOADER ####
    // #######################
    Loader: function() {
    }
});
